@@ -1,6 +1,7 @@
 from mlflow.entities._mlflow_object import _MLflowObject
 from mlflow.entities.auth_enums import PrivacyType
 from mlflow.entities.experiment_tag import ExperimentTag
+from mlflow.exceptions import MlflowException
 from mlflow.protos.service_pb2 import Experiment as ProtoExperiment
 from mlflow.protos.service_pb2 import ExperimentTag as ProtoExperimentTag
 
@@ -25,6 +26,8 @@ class Experiment(_MLflowObject):
         num_user_collaborators=None,
         description=None,
         privacy_type=PrivacyType.PRIVATE,
+        created_at=None,
+        tenant_name=None,
     ):
         super().__init__()
         self._experiment_id = experiment_id
@@ -38,6 +41,8 @@ class Experiment(_MLflowObject):
         self._num_user_collaborators = num_user_collaborators
         self._description = description
         self._privacy_type = PrivacyType(privacy_type)
+        self._created_at = created_at
+        self._tenant_name = tenant_name
 
     @property
     def experiment_id(self):
@@ -53,7 +58,7 @@ class Experiment(_MLflowObject):
         self._name = new_name
 
     @property
-    def artifact_location(self):
+    def artifact_location(self) -> str:
         """String corresponding to the root artifact URI for the experiment."""
         return self._artifact_location
 
@@ -95,6 +100,16 @@ class Experiment(_MLflowObject):
     def privacy_type(self):
         return self._privacy_type
 
+    @property
+    def created_at(self):
+        return self._created_at
+
+    @property
+    def tenant_name(self):
+        if not self._tenant_name:
+            raise MlflowException("tenant_name is not set")
+        return self._tenant_name
+
     @classmethod
     def from_proto(cls, proto):
         experiment = cls(
@@ -108,6 +123,8 @@ class Experiment(_MLflowObject):
             num_user_collaborators=proto.num_user_collaborators,
             description=proto.description,
             privacy_type=proto.privacy_type,
+            created_at=proto.created_at,
+            tenant_name=proto.tenant_name,
         )
         for proto_tag in proto.tags:
             experiment._add_tag(ExperimentTag.from_proto(proto_tag))
@@ -128,4 +145,7 @@ class Experiment(_MLflowObject):
         experiment.num_user_collaborators = self.num_user_collaborators
         experiment.description = self.description or ""
         experiment.privacy_type = self.privacy_type.value
+        if self.created_at:
+            experiment.created_at = self.created_at
+        experiment.tenant_name = self.tenant_name
         return experiment
