@@ -571,6 +571,16 @@ class RestStore(AbstractStore):
         response_proto = self._call_endpoint(mlfa_pb2.GetModelByFqn, request_body)
         return Model.from_proto(response_proto.model)
 
+    def get_model_by_name(
+        self,
+        experiment_id: int,
+        name: str,
+    ) -> Model:
+        message = mlfa_pb2.GetModelByName(experiment_id=str(experiment_id), name=name)
+        request_body = message_to_json(message)
+        response_proto = self._call_endpoint(mlfa_pb2.GetModelByName, request_body)
+        return Model.from_proto(response_proto.model)
+
     def create_model_version(
         self,
         artifact_version_id: uuid.UUID,
@@ -650,7 +660,7 @@ class RestStore(AbstractStore):
         custom_metrics: typing.List[CustomMetric],
     ) -> ModelVersion:
         message = mlfa_pb2.AddCustomMetricsToModelVersion(
-            id=str(version_id), custom_metrics=[cm.dict() for cm in custom_metrics]
+            id=str(version_id), custom_metrics=[cm.to_proto() for cm in custom_metrics]
         )
         request_body = message_to_json(message)
         response_proto = self._call_endpoint(mlfa_pb2.AddCustomMetricsToModelVersion, request_body)
