@@ -599,6 +599,9 @@ class TrackingServiceClient:
     def get_model_by_fqn(self, fqn: str) -> Model:
         return self.store.get_model_by_fqn(fqn=fqn)
 
+    def get_model_by_name(self, experiment_id: int, name: str) -> Model:
+        return self.store.get_model_by_name(experiment_id=experiment_id, name=name)
+
     def create_model_version(
         self,
         artifact_version_id: uuid.UUID,
