@@ -1826,6 +1826,9 @@ class MlflowClient:
     def get_model_by_fqn(self, fqn: str) -> Model:
         return self._tracking_client.get_model_by_fqn(fqn=fqn)
 
+    def get_model_by_name(self, experiment_id: int, name: str) -> Model:
+        return self._tracking_client.get_model_by_name(experiment_id=experiment_id, name=name)
+
     def create_model_version(
         self,
         artifact_version_id: uuid.UUID,
